SupportsOnConflictClause

Trait SupportsOnConflictClause 

pub trait SupportsOnConflictClause { }
Available on crate feature i-implement-a-third-party-backend-and-opt-into-breaking-changes only.
A marker trait indicating if a ON CONFLICT clause is supported or not

If you use a custom type to specify specialized support for ON CONFLICT clauses implementing this trait opts into reusing diesels existing ON CONFLICT QueryFragment implementations

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors